==> ZenTaoPMS.max2.0.rc1.php7.0.zip: zentaopms/module/milestone/lang/en.php <==
<?php
$lang->milestone->common      = 'Project Milestone Report';
$lang->milestone->index       = 'Milestone Home';
$lang->milestone->title       = 'Milestone Report';
$lang->milestone->name        = 'Milestone Name';
$lang->milestone->stage       = 'Milestone Stage';
$lang->milestone->save        = 'Save';

$lang->milestone->indexAction = 'Milestone Report';

$lang->milestone->startedWeeks  = 'Started Weeks';
$lang->milestone->finishedWeeks = 'Finished Weeks';
$lang->milestone->offset        = 'Milestone Deviation';

$lang->milestone->processCommon = 'Project Current Status';
$lang->milestone->process       = 'Project Schedule';
$lang->milestone->executionCost   = 'Project Cost';
$lang->milestone->toNow         = 'So far';
$lang->milestone->targetRange   = 'Target Range';
$lang->milestone->ge            = 'ge';
$lang->milestone->le            = 'le';
$lang->milestone->analysis      = 'Analysis';
$lang->milestone->PV            = 'The work to be done(PV)';
$lang->milestone->EV            = 'Actual work done(EV)';
$lang->milestone->AC            = 'Actual cost(AC)';
$lang->milestone->SPI           = 'Project schedule performance(SPI)';
$lang->milestone->CPI           = 'Project cost performance(CPI)';
$lang->milestone->SV            = 'Rate of progress deviation(SV%)';
$lang->milestone->CV            = 'Cost deviation rate(CV%)';

$lang->milestone->workHours   = 'Workload (man-hour)';
$lang->milestone->allStage    = 'Project Stage';
$lang->milestone->devHours    = 'Development Workload';
$lang->milestone->toHours     = 'Rework Workload';
$lang->milestone->reviewHours = 'Review Hours';
$lang->milestone->qaHours     = 'Test Workload';
$lang->milestone->rowSummary  = 'Workload Subtotal';
$lang->milestone->rowPercent  = 'Percentage Distribution(%)';
$lang->milestone->colPercent  = 'Percentage of workload(%)';
$lang->milestone->colSummary  = 'Total';
$lang->milestone->qatoDev     = 'Test Development ratio';

$lang->milestone->executionRisk     = '5.Project Risks (top five highest priority risks)';
$lang->milestone->riskCountermove = 'Risk Countermove';
$lang->milestone->riskDescriptio  = 'Risk Description';
$lang->milestone->riskPossibility = 'Risk Possibility';
$lang->milestone->riskSeriousness = 'Risk Seriousness';
$lang->milestone->riskFactor      = 'Risk Factor';
$lang->milestone->riskMeasures    = 'Risk Measures';
$lang->milestone->riskAccumulate  = 'Risk Accumulate';

$lang->milestone->otherIssue       = 'Other Issue';
$lang->milestone->issueSolutions   = 'Issue Solutions';
$lang->milestone->issueDescription = 'Issue Description';
$lang->milestone->needHelp         = 'Help';
$lang->milestone->issuePropose     = 'Issue Propose';

$lang->milestone->demandStatus     = '4.Customer Demand Analysis';
$lang->milestone->storyUnit        = 'Unit:Item';
$lang->milestone->engineeringStage = 'Engineering Stage';
$lang->milestone->rateChange       = 'Rate of change in demand';
$lang->milestone->originalStory    = 'Quantity of original demand';
$lang->milestone->modifyNumber     = 'Total post-change requirements';
$lang->milestone->changeStory      = 'Number of changed requirements';

$lang->milestone->paogressForecast   = 'Project Forecast';
$lang->milestone->duration           = 'Construction period(day)';
$lang->milestone->cost               = 'Cost(hours)';
$lang->milestone->forecastResults    = 'Forecast Results';
$lang->milestone->plannedValue       = 'Planned Value';
$lang->milestone->predictedValue     = 'Predicted Value';
$lang->milestone->predictedValueDesc = 'Rentenformel (Germany)：If the execution progress performance(SPI)=0,So the predicted value=0,Otherwise,Predicted value=Planned value divided by Project schedule performance(SPI)';
$lang->milestone->periodDeviation    = 'Period Deviation';
$lang->milestone->costDeviation      = 'Cost Deviation';
$lang->milestone->nextStage          = 'Next Stage';
$lang->milestone->overallProject     = 'Overall Project';
$lang->milestone->corrective         = 'Corrective Measure';
$lang->milestone->timeOverrun        = 'The total construction time will exceed:%s day.';
$lang->milestone->costOverrun        = 'The total cost will exceed:%s unit';
$lang->milestone->saveOtherProblem   = 'Save Other Problem';

$lang->milestone->chart = new stdclass();
$lang->milestone->chart->title    = 'Trend Chart of execution progress to date';
$lang->milestone->chart->time     = 'No';
$lang->milestone->chart->week     = 'week';
$lang->milestone->chart->month    = 'month';
$lang->milestone->chart->workhour = 'Development Workload Analysis Chart';

$lang->milestone->otherproblem      = '6.Other Problem';
$lang->milestone->problemandsuggest = 'Problem and Suggest';
$lang->milestone->suggest           = 'Suggest';
$lang->milestone->needhelp          = 'Does it require high-level support?';
$lang->milestone->prodescr          = 'Problem Description';

$lang->milestone->quality = new stdclass();
$lang->milestone->quality->total         = 'Total';
$lang->milestone->quality->identify      = 'Defect identification phase';
$lang->milestone->quality->injection     = 'Defect injection phase';
$lang->milestone->quality->scale         = 'Scale';
$lang->milestone->quality->identifyRate       = 'Defect recognition rate';
$lang->milestone->quality->injectionRate      = 'Defect injection rate';

$lang->milestone->options  = 'Options';

==> ZenTaoPMS.max2.7.php5.3_5.6.zip: zentaopms/module/milestone/lang/en.php <==
<?php
$lang->milestone->common      = 'Project Milestone Report';
$lang->milestone->index       = 'Milestone Home';
$lang->milestone->title       = 'Milestone Report';
$lang->milestone->name        = 'Milestone Name';
$lang->milestone->stage       = 'Milestone Stage';
$lang->milestone->save        = 'Save';

$lang->milestone->indexAction = 'Milestone Report';

$lang->milestone->startedWeeks  = 'Started Weeks';
$lang->milestone->finishedWeeks = 'Finished Weeks';
$lang->milestone->offset        = 'Milestone Deviation';

$lang->milestone->processCommon = 'Project Current Status';
$lang->milestone->process       = 'Project Schedule';
$lang->milestone->executionCost   = 'Project Cost';
$lang->milestone->toNow         = 'So far';
$lang->milestone->targetRange   = 'Target Range';
$lang->milestone->ge            = 'ge';
$lang->milestone->le            = 'le';
$lang->milestone->analysis      = 'Analysis';
$lang->milestone->PV            = 'The work to be done(PV)';
$lang->milestone->EV            = 'Actual work done(EV)';
$lang->milestone->AC            = 'Actual cost(AC)';
$lang->milestone->SPI           = 'Project schedule performance(SPI)';
$lang->milestone->CPI           = 'Project cost performance(CPI)';
$lang->milestone->SV            = 'Rate of progress deviation(SV%)';
$lang->milestone->CV            = 'Cost deviation rate(CV%)';

$lang->milestone->workHours   = 'Workload (man-hour)';
$lang->milestone->allStage    = 'Project Stage';
$lang->milestone->devHours    = 'Development Workload';
$lang->milestone->toHours     = 'Rework Workload';
$lang->milestone->reviewHours = 'Review Hours';
$lang->milestone->qaHours     = 'Test Workload';
$lang->milestone->rowSummary  = 'Workload Subtotal';
$lang->milestone->rowPercent  = 'Percentage Distribution(%)';
$lang->milestone->colPercent  = 'Percentage of workload(%)';
$lang->milestone->colSummary  = 'Total';
$lang->milestone->qatoDev     = 'Test Development ratio';

$lang->milestone->executionRisk     = '5.Project Risks (top five highest priority risks)';
$lang->milestone->riskCountermove = 'Risk Countermove';
$lang->milestone->riskDescriptio  = 'Risk Description';
$lang->milestone->riskPossibility = 'Risk Possibility';
$lang->milestone->riskSeriousness = 'Risk Seriousness';
$lang->milestone->riskFactor      = 'Risk Factor';
$lang->milestone->riskMeasures    = 'Risk Measures';
$lang->milestone->riskAccumulate  = 'Risk Accumulate';

$lang->milestone->otherIssue       = 'Other Issue';
$lang->milestone->issueSolutions   = 'Issue Solutions';
$lang->milestone->issueDescription = 'Issue Description';
$lang->milestone->needHelp         = 'Help';
$lang->milestone->issuePropose     = 'Issue Propose';

$lang->milestone->demandStatus     = '4.Customer Demand Analysis';
$lang->milestone->storyUnit        = 'Unit:Item';
$lang->milestone->engineeringStage = 'Engineering Stage';
$lang->milestone->rateChange       = 'Rate of change in demand';
$lang->milestone->originalStory    = 'Quantity of original demand';
$lang->milestone->modifyNumber     = 'Total post-change requirements';
$lang->milestone->changeStory      = 'Number of changed requirements';

$lang->milestone->paogressForecast   = 'Project Forecast';
$lang->milestone->duration           = 'Construction period(day)';
$lang->milestone->cost               = 'Cost(hours)';
$lang->milestone->forecastResults    = 'Forecast Results';
$lang->milestone->plannedValue       = 'Planned Value';
$lang->milestone->predictedValue     = 'Predicted Value';
$lang->milestone->predictedValueDesc = 'Rentenformel (Germany)：If the execution progress performance(SPI)=0,So the predicted value=0,Otherwise,Predicted value=Planned value divided by Project schedule performance(SPI)';
$lang->milestone->periodDeviation    = 'Period Deviation';
$lang->milestone->costDeviation      = 'Cost Deviation';
$lang->milestone->nextStage          = 'Next Stage';
$lang->milestone->overallProject     = 'Overall Project';
$lang->milestone->corrective         = 'Corrective Measure';
$lang->milestone->timeOverrun        = 'The total construction time will exceed:%s day.';
$lang->milestone->costOverrun        = 'The total cost will exceed:%s unit';
$lang->milestone->saveOtherProblem   = 'Save Other Problem';

$lang->milestone->chart = new stdclass();
$lang->milestone->chart->title    = 'Trend Chart of execution progress to date';
$lang->milestone->chart->time     = 'No';
$lang->milestone->chart->week     = 'week';
$lang->milestone->chart->month    = 'month';
$lang->milestone->chart->workhour = 'Development Workload Analysis Chart';

$lang->milestone->otherproblem      = '6.Other Problem';
$lang->milestone->problemandsuggest = 'Problem and Suggest';
$lang->milestone->suggest           = 'Suggest';
$lang->milestone->needhelp          = 'Does it require high-level support?';
$lang->milestone->prodescr          = 'Problem Description';

$lang->milestone->reviewHoursTip = 'Review Hours = Reviewed Hours * Reviewer Count';
$lang->milestone->toHoursTip     = "Rework Workload counts the Reconsumed work hours after task is activated";

$lang->milestone->quality = new stdclass();
$lang->milestone->quality->total         = 'Total';
$lang->milestone->quality->identify      = 'Defect identification phase';
$lang->milestone->quality->injection     = 'Defect injection phase';
$lang->milestone->quality->scale         = 'Scale';
$lang->milestone->quality->identifyRate  = 'Defect recognition rate';
$lang->milestone->quality->injectionRate = 'Defect injection rate';

$lang->milestone->options  = 'Options';
